import 'package:domain/entity/rewards_detail_entity.dart';
import 'package:flutter/material.dart';
import 'package:plugin_platform/http/http_result.dart';
import 'package:riverpod_annotation/riverpod_annotation.dart';
import 'package:shared/utils/log_utils.dart';
import 'package:plugin_platform/engine/toast/toast_engine.dart';
import 'package:widgets/load_state_layout.dart';
import 'package:widgets/picker/option_pick_util.dart';
import 'package:widgets/widget_export.dart';
import './rewards_detail_state.dart';
import './rewards_detail_repository.dart';
part 'rewards_detail_vm.g.dart';

@riverpod
class RewardsDetailVm extends _$RewardsDetailVm {
  late RewardsDetailRepository rewardsDetailRepository;
  bool _needShowPlaceholder = false; //是否展示LoadingView

  // Refresh 控制器
  final EasyRefreshController refreshController = EasyRefreshController(
    controlFinishRefresh: true, //允许刷新
    controlFinishLoad: true, //允许加载
  );
  RewardsDetailState initState() {
    return RewardsDetailState();
  }

  @override
  RewardsDetailState build() {
    // 引入数据仓库
    rewardsDetailRepository = ref.read(rewardsDetailRepositoryProvider);
    // 初始化状态
    RewardsDetailState state = initState();
    // 初始化列表数据
    Log.d("state.list------${state.detailInfo}");
    return state;
  }

  // 初始化页面数据
  initPageData({int? id}) {
    Log.d("----property_news_vm-----initPageData");
    getListData(id: id);
  }

  // 上拉加载
  Future onLoadData() async {
    Log.d("----property_news_vm-----initListData");
    getListData();
  }

// 去新闻详情页
  void goNewsDetail(String item) {
    Log.d(item);
    // PropertyPage.startInstance(context: context, item: item);
  }

// 重试请求
  Future retryRequest({int? id}) async {
    _needShowPlaceholder = true;
    getListData(id: id);
  }

  //刷新页面状态
  void changeLoadingState(LoadState loadState, String? errorMsg) {
    state = state.copyWith(loadingState: loadState, errorMessage: errorMsg);
  }

  // 获取list 列表数据
  void getListData<T>({int? id}) async {
    Log.d("加载listData数据---------------start-----");
    try {
      //请求网络
      Map<String, dynamic> params = {"id": id};
      Log.d("请求参数------$params");
      final result =
          await rewardsDetailRepository.fetchPropertyNewsList(params);
      Log.d("请求完成结果------${result.data}");
      //校验成功失败
      if (result.isSuccess) {
        state = state.copyWith(
          detailInfo: result.data as RewardsDetailEntity,
        );
        Log.d("123------${state.detailInfo}");
        changeLoadingState(LoadState.State_Success, null);
      } else {
        String errorMessage = result.errorMsg!;
        changeLoadingState(LoadState.State_Error, errorMessage);
        ToastEngine.show(result.errorMsg ?? "Network Load Error");
      }
    } catch (e) {
      ToastEngine.show("Error: $e");
    }
  }
  // // 下拉刷新
  // Future refreshListData() async {
  //   Log.d("----property_news_vm-----refreshListData ");

  //   // await Future.delayed(const Duration(seconds: 2));

  //   state = state.copyWith(curPage: 1, pageSize: 10);
  //   // ref.invalidateSelf();
  //   // ref.invalidate(propertyNewsVmProvider);
  //   getListData();
  // }
}
